write_batches_to_object_store

Function write_batches_to_object_store 

pub async fn write_batches_to_object_store(
    batches: &[RecordBatch],
    object_store: Arc<dyn ObjectStore>,
    path: &Path,
    compression: Option<Compression>,
    max_row_group_size: Option<usize>,
    key_value_metadata: Option<Vec<KeyValue>>,
) -> Result<()>
Writes multiple RecordBatch items to an object store URI, with optional compression, row group sizing, and key_value_metadata (e.g. for instrument “class” so it survives roundtrip).

Errors

Returns an error if writing to Parquet fails or any I/O operation fails.